==> libnokogiri-ruby_1.3.1.orig.tar.gz: nokogiri-1.3.1/test/html/test_element_description.rb <==
require File.expand_path(File.join(File.dirname(__FILE__), '..', "helper"))

module Nokogiri
  module HTML
    class TestElementDescription < Nokogiri::TestCase
      def test_fetch_nonexistent
        assert_nil ElementDescription['foo']
      end

      def test_fetch_element_description
        assert desc = ElementDescription['a']
        assert_instance_of ElementDescription, desc
      end

      def test_name
        assert_equal 'a', ElementDescription['a'].name
      end

      def test_implied_start_tag?
        assert !ElementDescription['a'].implied_start_tag?
      end

      def test_implied_end_tag?
        assert !ElementDescription['a'].implied_end_tag?
        assert ElementDescription['p'].implied_end_tag?
      end

      def test_save_end_tag?
        assert !ElementDescription['a'].save_end_tag?
        assert ElementDescription['br'].save_end_tag?
      end

      def test_empty?
        assert ElementDescription['br'].empty?
        assert !ElementDescription['a'].empty?
      end

      def test_deprecated?
        assert ElementDescription['applet'].deprecated?
        assert !ElementDescription['br'].deprecated?
      end

      def test_inline?
        assert ElementDescription['a'].inline?
        assert !ElementDescription['div'].inline?
      end

      def test_block?
        element = ElementDescription['a']
        assert_equal(!element.inline?, element.block?)
      end

      def test_description
        assert ElementDescription['a'].description
      end

      def test_subelements
        sub_elements = ElementDescription['body'].sub_elements
        assert_equal 61, sub_elements.length
      end

      def test_default_sub_element
        assert_equal 'div', ElementDescription['body'].default_sub_element
      end

      def test_optional_attributes
        attrs = ElementDescription['table'].optional_attributes
        assert attrs
        assert_equal 22, attrs.length
      end

      def test_deprecated_attributes
        attrs = ElementDescription['table'].deprecated_attributes
        assert attrs
        assert_equal 2, attrs.length
      end

      def test_required_attributes
        attrs = ElementDescription['table'].required_attributes
        assert attrs
        assert_equal 0, attrs.length
      end

      def test_inspect
        desc = ElementDescription['input']
        assert_match desc.name, desc.inspect
      end

      def test_to_s
        desc = ElementDescription['input']
        assert_match desc.name, desc.to_s
      end
    end
  end
end

==> libnokogiri-ruby_1.4.0.orig.tar.gz: nokogiri-1.4.0/test/html/test_element_description.rb <==
require "helper"

module Nokogiri
  module HTML
    class TestElementDescription < Nokogiri::TestCase
      def test_fetch_nonexistent
        assert_nil ElementDescription['foo']
      end

      def test_fetch_element_description
        assert desc = ElementDescription['a']
        assert_instance_of ElementDescription, desc
      end

      def test_name
        assert_equal 'a', ElementDescription['a'].name
      end

      def test_implied_start_tag?
        assert !ElementDescription['a'].implied_start_tag?
      end

      def test_implied_end_tag?
        assert !ElementDescription['a'].implied_end_tag?
        assert ElementDescription['p'].implied_end_tag?
      end

      def test_save_end_tag?
        assert !ElementDescription['a'].save_end_tag?
        assert ElementDescription['br'].save_end_tag?
      end

      def test_empty?
        assert ElementDescription['br'].empty?
        assert !ElementDescription['a'].empty?
      end

      def test_deprecated?
        assert ElementDescription['applet'].deprecated?
        assert !ElementDescription['br'].deprecated?
      end

      def test_inline?
        assert ElementDescription['a'].inline?
        assert !ElementDescription['div'].inline?
      end

      def test_block?
        element = ElementDescription['a']
        assert_equal(!element.inline?, element.block?)
      end

      def test_description
        assert ElementDescription['a'].description
      end

      def test_subelements
        sub_elements = ElementDescription['body'].sub_elements
        assert_equal 61, sub_elements.length
      end

      def test_default_sub_element
        assert_equal 'div', ElementDescription['body'].default_sub_element
      end

      def test_optional_attributes
        attrs = ElementDescription['table'].optional_attributes
        assert attrs
      end

      def test_deprecated_attributes
        attrs = ElementDescription['table'].deprecated_attributes
        assert attrs
        assert_equal 2, attrs.length
      end

      def test_required_attributes
        attrs = ElementDescription['table'].required_attributes
        assert attrs
        assert_equal 0, attrs.length
      end

      def test_inspect
        desc = ElementDescription['input']
        assert_match desc.name, desc.inspect
      end

      def test_to_s
        desc = ElementDescription['input']
        assert_match desc.name, desc.to_s
      end
    end
  end
end
